@@ -84,7 +84,7 @@
 #define KITEMVIEWS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMVIEWS_NO_DEPRECATED
-#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KITEMVIEWS_NO_DEPRECATED_WARNINGS
 #  define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
